---
name: Feature request
about: Suggest an idea for this project

---

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is, for example:

As a [...] I want [...] so that [...]

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Acceptance criteria**
Please specify the acceptance criteria in as much detail as possible,
for example:

- if this feature is available how would you invoke it (code example)
- what would the output look like?
    - if it is an object, what would the members be?
    - if it is a plot, a sketch would help
    - anything else that clarifies what would constitute a satisfactory
      implementation?

**Additional context**
Add any other context or screenshots about the feature request here.
